rm(list=ls())
gc()

list_packages <- c("textclean", "tm" , "SnowballC", "wordcloud", "textstem",  "quanteda", "lmtest", "sandwich","ggplot2", "stargazer", "DBI", "readstata13", "haven", "dplyr", "readxl", "stringr", "ggrepel", "tidyverse")
lapply(list_packages,function(x){library(x,character.only=TRUE)})

#### Define Paths ####
setwd("/Users/beatrice/Desktop/REPLICATION_PACKET")


options(digits = 4)
wd <- file.path(getwd())
data <- file.path(getwd(), 'Data')
figures <- file.path(getwd(), 'Output')



#### Define helper functions ####

wcloud <- function(data, compare, namegrams, question, groupvar=NULL, max_pct){
  w = 7
  
  pdf(file.path(figures,paste('Figure_1a.pdf')), width=w)
  col <- sapply(seq(0.3, 1, 0.1), function(x) adjustcolor("#0f2f61", x))
  max_size<- max_pct/8.9*5 #8.9 is the max_pct across the three questions, 4.5 is the maximum size we want
  textplot_wordcloud(data,comparison=compare, min_count=5, min_size=0.5, max_size=max_size,  color = col, rotation=0, fixed_aspect=TRUE, max_words=200)
  dev.off()
}



export_keyness <- function(this_data, grams, comparison_var, comparison_values, question_number){ 
  w <- 10
  min_count<-10
  
  thisdfm <- this_data[docvars(this_data, comparison_var) %in% comparison_values,]
  
  thisdfm <- dfm_group(thisdfm, groups=comparison_var)
  
  print(thisdfm)
  
  this_key <-textstat_keyness(thisdfm) 
  this_key$feature <- quanteda::tokens(this_key$feature) %>% # split the words
    lapply(sort) %>% # sort the words
    sapply(paste, collapse = " ")
  this_key <- this_key[ntype(this_key$feature)>=2]
  this_key$feature <- str_squish(this_key$feature)
  this_key <- this_key %>%
    group_by(feature) %>%
    summarise(n_target = sum(n_target), n_reference = sum(n_reference)) 
  
  for (i in c(1:nrow(this_key))) {
    a <- this_key$n_target[i]
    b <- this_key$n_reference[i]
    c <- sum(this_key$n_target[-i])
    d <- sum(this_key$n_reference[-i])
    N = (a+b+c+d)
    E = (a+b)*(a+c) / N
    cor_app <- (((a + b) * (a + c) / N < 5 | (a + b) * (b + d) / N < 5 |
                   (a + c) * (c + d) / N < 5 | (c + d) * (b + d) / N < 5) & abs(a * d - b * c) >= N / 2)
    this_key$chi2[i] <- ifelse(cor_app,
                               (N * (abs(a * d - b * c) - N * 0.5) ^ 2) /
                                 ((a + b) * (c + d) * (a + c) * (b + d)) * ifelse(a > E, 1, -1),
                               (N * abs(a * d - b * c) ^ 2) /
                                 ((a + b) * (c + d) * (a + c) * (b + d)) * ifelse(a > E, 1, -1))
    this_key$p[i] <- 1 - stats::pchisq(abs(this_key$chi2[i]), 1)
  }
  
  this_key$n_target <- mapply(clever_function, this_key$p, this_key$n_target)
  this_key$n_reference <- mapply(clever_function, this_key$p, this_key$n_reference)
  
  this_key <- this_key[this_key$p!='NaN',]
  this_key <- this_key[this_key$p<=0.1,]
  this_key <- this_key[(this_key$n_target>=min_count | this_key$n_reference>=min_count),]
  
  this_key$feature <- mapply(pretty_format, this_key$feature, this_key$p)
  
  graph_data <- this_key  %>% mutate(question = !!question_number) %>%
    mutate(comparison_variable = !!comparison_var) %>%
    mutate(group_name = ifelse(chi2 > 0, comparison_values[2],comparison_values[1])) %>% arrange(chi2)
  
  return(graph_data)
  
}

pretty_format <- function(text, pval){
  if (is.na(pval)) {
    text <- text
  } else if (pval<=0.01){
    text <- paste(text, " ***", sep="")
  } else if (pval<=0.05){
    text <- paste(text, " **", sep = "")
  } else if (pval<=0.10){
    text <- paste(text, " *", sep="")
  } 
  return(text)
}

clever_function <- function(pval, n_value){
  if (is.na(pval)) { } else if (pval>0.10){
    n_value <- 0
  } 
  return(n_value)
}

remove_underscore <- function(textin){
  textin <- gsub("_"," ",textin)
  return(textin)
}


####################
##Implementation ##
####################

## Questions of block 2

qlabels <- readxl::read_xlsx(file.path(data, 'Open_Answers_Labels_trim_income.xlsx'),sheet="Sheet1")
qlabels <- qlabels[!is.na(qlabels$QID),]

qlabels$text_trim<-as.character(qlabels$text_trim)
qlabels$wc_text_trim<-as.character(qlabels$wc_text_trim)

df <- read_dta(file.path(data,'data_income_tax.dta'))

# Create group categories for the keyness graphs
df$screen <- as.numeric(df$screen)
df <- df[!is.na(df$screen),]




# (Re)create pooled variable for answers, when subject to randomization


qlabels <- qlabels[1:1,] 
keyness_data_income = data.frame() #the keyness graph data will be collected in this frame

for (qid in qlabels$QID){
  
  
  #### Create new categories for keyness graphs ####
  
  df_sub <- df[which(df[,qid]!=""),]
  df_sub$affiliation <- df_sub$G01020
  df_sub$affiliation[df_sub$G01020=='Independent'] <- "Other" 
  df_sub$affiliation[df_sub$G01020=='Non-Affiliated'] <- "Other" 
  
  
  #### First cleaning: case, apostrophes, punctuation, numbers  #### 
  
  #convert to lower case
  df_sub[qid] <- lapply(df_sub[qid],function(x) char_tolower(as.character(x)))
  
  #apostrophes and specific punctuation
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("'","'",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("’","'",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("′","'",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\'s",' ',as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\' s",' ',as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub(",",'',as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("[\\$,]","",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub(";",' ',as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\b1 %",'xyzxyz',as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\b1 percent ",'xyzxyz',as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\bone percent ",'xyzxyz',as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub(" \\b%",'percent',as.character(x)))
  
  #replace numbers
  df_sub[qid] <- lapply(df_sub[qid],function(x) replace_number(x))
  
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\bxyzxyz",'1 percent',as.character(x)))
  
  
  
  #### Lemmatization ####
  
  #don't 
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\bdon't "," donnnt ",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("doesn't","does not",as.character(x)))
  #can't
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("can't","cannnot",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\bcan t ","cannnot",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("cannot","cannnot",as.character(x)))
  #working class
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("working","workingggg",as.character(x)))
  #united states
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\bu\\.s","uuunited ssstates",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\busa","uuunited ssstates",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("united states","uuunited ssstates",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\bus ","uuunited ssstates ",as.character(x)))
  #complicated
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\bcomplicated","complicateddd",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\blower","lowerrr",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\bhigher","higherrr",as.character(x)))
  #every one / every person / everyone
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\bevery one","everyone",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\bevery person","everyone",as.character(x)))
  #spending
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\bspending","spendingggg",as.character(x)))
  
  # Replace contractions and lemmatize
  
  df_sub[qid] <- lapply(df_sub[qid], replace_contraction)
  df_sub[qid] <- lapply(df_sub[qid],function(x) char_tolower(as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid], lemmatize_strings)
  
  # Getting back expressions
  
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("workingggg","working",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("uuunited ssstates","usa",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\bcannnot","cant",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\bdonnnt","dont",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("complicateddd","complicated",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("lowerrr","lower",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("higherrr","higher",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("spendingggg","spending",as.character(x)))
  
  # Additional cleaning 
  
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\btake advantage","take_advantage",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\bmake sure","ensure",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\btax payer","taxpayer",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\bceos","ceo",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\bloop hole","loophole",str_squish(as.character(x))))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\bfind way around","avoid",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\bfind way","avoid",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\bfind a way around","avoid",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\bget away","avoid",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\bas long as","if",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\bhealth care","healthcare",as.character(x)))
  
  #zero (1gram into 2grams)
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("^zero$","zero percent",as.character(x))) 
  
  
  
  #### Remove stopwords ####
  
  sw <- stopwords("english")
  sw <- sw[!sw %in% c("few", "not", "no", "too", "very")]
  #, "same", "more", "all", "up", "down")]
  df_sub[qid] <- lapply(df_sub[qid], function(x) removeWords(x, sw))
  df_sub[qid] <- lapply(df_sub[qid], function(x) removePunctuation(x))
  df_sub[qid] <- lapply(df_sub[qid], function(x) gsub('"[[:punct:][:blank:]]+"',' ',as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid], function(x) str_squish(as.character(x)))  
  df_sub[qid] <- lapply(df_sub[qid], function(x) gsub("“", "", as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid], function(x) gsub("”", "", as.character(x)))
  
  # Save expressions
  
  #too
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\btoo much","too_much",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\btoo many","too_many",as.character(x)))
  #no
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\bdont ([a-z]+ ){0,5}opinion","nooopinion \\1 \\2 \\3 \\4 \\5",as.character(x))) 
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\bno idea","nooopinion",as.character(x))) 
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\bno clue","nooopinion",as.character(x))) 
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\bno comment","nooopinion",as.character(x))) 
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\bno consideration","nooopinion",as.character(x))) 
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\bno tax","noootax",as.character(x))) 
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\bnone tax","noootax",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\bnot tax","noootax",as.character(x)))
  #not
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\bnot ([a-z]+ ){0,1}sure","notttsuuure \\1",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\bnot ([a-z]+ ){0,1}fair","notttfair \\1",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\bnot ([a-z]+ ){0,1}know","dontttknow \\1",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("\\bnot work","notttwork",as.character(x)))
  #dont
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("dont know","dontttknow",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("dont tax","dontttax",as.character(x)))
  
  # Remove words
  
  df_sub[qid] <- lapply(df_sub[qid],function(x) removeWords(x, c("not", "no", "too", "dont")))
  
  
  # Retrieve saved expressions
  
  #too
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("toooomuch","too_much",str_squish(as.character(x))))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("toooomany","too_many",as.character(x)))
  # no
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("noootax","no tax",as.character(x)))  
  #not
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("notttfair","not fair",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("unfair","not fair",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("notttwork","not_work",as.character(x)))
  #dont
  df_sub[qid] <- lapply(df_sub[qid],function(x) removeWords(x, "dont"))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("dontttax","dont tax",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("dontttknow","dont know",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("idk","dont know",as.character(x)))
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("nooopinion","dont know",as.character(x))) 
  df_sub[qid] <- lapply(df_sub[qid],function(x) gsub("notttsuuure","dont know",as.character(x)))
  
  
  
  #### Treat expressions using "tax" ####
  
  # tax and taxation
  df_sub[qid] <- lapply(df_sub[qid], function(x) gsub("taxation","tax",as.character(x)))
  
  df_sub[qid] <- lapply(df_sub[qid], function(x) gsub("double ([a-z]+ ){0,1}tax\\b", "double taxation \\1", str_squish(as.character(x))))
  df_sub[qid] <- lapply(df_sub[qid], function(x) gsub("already ([a-z]+ ){0,1}tax\\b", "double taxation \\1",str_squish(as.character(x))))
  df_sub[qid] <- lapply(df_sub[qid], function(x) gsub("tax ([a-z]+ ){0,1}already\\b", "double taxation \\1", str_squish(as.character(x))))
  df_sub[qid] <- lapply(df_sub[qid], function(x) gsub("flat ([a-z]+ ){0,1}tax\\b", "flat taxation \\1", str_squish(as.character(x))))
  df_sub[qid] <- lapply(df_sub[qid], function(x) gsub("flat ([a-z]+ ){0,3}rate\\b", "flat taxation \\1 \\2 \\3", str_squish(as.character(x))))
  df_sub[qid] <- lapply(df_sub[qid], function(x) gsub("progressive ([a-z]+ ){0,1}tax\\b", "progressive taxation \\1", str_squish(as.character(x))))
  df_sub[qid] <- lapply(df_sub[qid], function(x) gsub("fair ([a-z]+ ){0,1}tax\\b", "fair taxation \\1", str_squish(as.character(x))))
  df_sub[qid] <- lapply(df_sub[qid], function(x) gsub("tax ([a-z]+ ){0,1}fair\\b", "fair taxation \\1", str_squish(as.character(x))))
  df_sub[qid] <- lapply(df_sub[qid], function(x) gsub("rich ([a-z]+ ){0,1}tax\\b", "rich taxation \\1", str_squish(as.character(x))))
  df_sub[qid] <- lapply(df_sub[qid], function(x) gsub("wealthy ([a-z]+ ){0,1}tax\\b", "wealthy taxation \\1", str_squish(as.character(x))))
  df_sub[qid] <- lapply(df_sub[qid], function(x) gsub("family ([a-z]+ ){0,1}tax\\b", "family taxation \\1", str_squish(as.character(x))))
  df_sub[qid] <- lapply(df_sub[qid], function(x) gsub("tax ([a-z]+ ){0,1}family\\b", "family taxation \\1", str_squish(as.character(x))))
  df_sub[qid] <- lapply(df_sub[qid], function(x) gsub("tax ([a-z]+ ){0,1}bracket\\b", "taxation bracket \\1", str_squish(as.character(x))))
  df_sub[qid] <- lapply(df_sub[qid], function(x) gsub("corporate ([a-z]+ ){0,1}tax\\b", "corporate taxation \\1", str_squish(as.character(x))))
  df_sub[qid] <- lapply(df_sub[qid], function(x) gsub("lower ([a-z]+ ){0,1}tax\\b", "lower taxation \\1", str_squish(as.character(x))))
  df_sub[qid] <- lapply(df_sub[qid], function(x) gsub("tax ([a-z]+ ){0,1}lower\\b", "lower taxation \\1", str_squish(as.character(x))))
  df_sub[qid] <- lapply(df_sub[qid], function(x) gsub("higher ([a-z]+ ){0,1}tax\\b", "higher taxation \\1", str_squish(as.character(x))))
  df_sub[qid] <- lapply(df_sub[qid], function(x) gsub("sale ([a-z]+ ){0,1}tax\\b", "sales taxation \\1", str_squish(as.character(x))))
  df_sub[qid] <- lapply(df_sub[qid], function(x) gsub("\\btax\\b", "taxxx", str_squish(as.character(x))))  
  df_sub[qid] <- lapply(df_sub[qid], function(x) gsub("\\btaxation\\b", "tax", str_squish(as.character(x))))
  
  df_sub[qid] <- lapply(df_sub[qid], function(x) removeWords(x, c("taxxx", "certain", "lot", "amount")))
  
  df_sub[qid] <- lapply(df_sub[qid], function(x) gsub("\\btake care", "take_care", str_squish(as.character(x))))
  
  
  #### Create corpus, remove punctation and common stopwords #### 
  
  mycorpus <- corpus(df_sub, docid_field = 'ResponseId', text_field = qid)
  toks<-quanteda::tokens(mycorpus, remove_punct=T)
  
  toks <- quanteda::tokens_select(toks, sw, selection='remove')
  
  #Trim specific words
  question_trim <- qlabels %>%
    filter(QID==qid) %>%
    select(text_trim)
  question_trim<-as.character(question_trim)
  question_trim <- quanteda::tokens(question_trim)
  question_trim <-  question_trim$text1
  
  toks <- tokens_select(toks, question_trim, selection='remove')
  
  #Create dfm
  ngdfm2 <- dfm(quanteda::tokens_ngrams(toks,n=2,concatenator = "_",skip=0:1))
  ngdfm2@Dimnames$features = sapply(ngdfm2@Dimnames$features, remove_underscore)
  
  ## Implementation
keyness_data_income <- keyness_data_income %>%
    bind_rows(export_keyness(ngdfm2, '2g', 'affiliation', c('Republican', 'Democrat'), qid)) 

  ####  Additional trim for wordclouds ("don't know" mainly) #### 
  
  
  
  mycorpus <- corpus(df_sub, docid_field = 'ResponseId', text_field = qid)
  toks<-tokens(mycorpus, remove_punct=T)
  toks <- tokens_select(toks, sw, selection='remove')
  question_trim <- qlabels %>%  filter(QID==qid) %>%  select(text_trim)
  question_trim <- as.character(question_trim)
  question_trim <- tokens(question_trim)
  question_trim <-  question_trim$text1
  
  toks <- tokens_select(toks, question_trim, selection='remove')
  
  wc_question_trim <- qlabels %>% filter(QID==qid) %>% select(wc_text_trim)
  wc_question_trim <- as.character(wc_question_trim)
  wc_question_trim <- tokens(wc_question_trim)
  wc_question_trim <-  wc_question_trim$text1
  
  toks_wc <- tokens_select(toks, wc_question_trim, selection='remove')
  
  #Create dfm
  
  ngdfm_wc <- dfm(toks_wc) %>%
    dfm_trim(min_termfreq = 5 )
  ngdfm_wc@Dimnames$features = sapply(ngdfm_wc@Dimnames$features, remove_underscore)
  
  ngdfm2_wc <- dfm(tokens_ngrams(toks_wc,n=2,concatenator = "_",skip=0:1))
  ngdfm2_wc@Dimnames$features = sapply(ngdfm2_wc@Dimnames$features, remove_underscore)
  
  
  ngdfm12_wc <- dfm(tokens_ngrams(toks_wc,n=1:2,concatenator = "_",skip=0:1))
  ngdfm12_wc@Dimnames$features = sapply(ngdfm12_wc@Dimnames$features, remove_underscore)
  
  #wcloud(ngdfm_wc, FALSE, '1g', qid)
  #wcloud(ngdfm12_wc, FALSE, '1-2g', qid)
  
  nrow <- nrow(df_sub[qid])
  dontknow<- length(sapply(df_sub[qid], function(x) grep("dont know",str_squish(x))))
  nrow <- nrow - dontknow
  if (qid=="Q02002") { max_freq<-length(sapply(df_sub[qid], function(x) grep("lower ([a-z]+ ){0,1}tax",str_squish(x)))) 
  max_pct<- max_freq/nrow*100}
  wcloud(ngdfm2_wc, FALSE, '2g', qid, max_pct=max_pct)
  
}


write_csv(keyness_data_income, path = file.path(data, "keyness_data_income.csv"))



######################
######################
# Produce graphs
######################
######################

#define export folder and load data
graph_data <- read.csv(file = file.path(data, "Figure_3a.csv")) %>%
  mutate(question_long = case_when(question  == "Q02002" ~ "Considerations")) %>%
  rename(label = feature) %>%
  filter(comparison_variable=="affiliation" & question_long=="Considerations")



for (split in graph_data %>% select(comparison_variable) %>% distinct() %>% pull()){
  
  blue_red <- c("#1a4065", "#b92a17")
  violet_green <- c("#5e0b58", "#4d854b") 
  
  if(split  == "affiliation"){
    colors <- blue_red
  }else{
    colors <- violet_green
  }
  
  
  input_data <- graph_data %>%
    filter(comparison_variable == !!split)
  
  
  
  graph <- input_data %>%
    ggplot() +
    geom_hline(yintercept = 0, linetype = "dashed", color = "black", size = 0.5) +
    geom_point(aes(x = question_long, y = chi2, color=group_name), shape = 18, size = 3) +
    geom_text_repel(data = . %>% filter(chi2 >=0), 
                    aes(x = question_long, y = chi2, 
                        label = label, color = group_name, size=100), 
                    segment.size = 0.4, hjust = 1, ylim=c(1, input_data %>% 
                                                            select(chi2) %>% 
                                                            abs() %>% 
                                                            max()+1), 
                    nudge_x = -0.04, nudge_y = 2, direction = "y", segment.colour = NA, show.legend = FALSE, box.padding = 0.08) +
    geom_text_repel(data = . %>% filter(chi2 <0), 
                    aes(x = question_long, y = chi2, label = label, color = group_name, size=100), segment.size = 0.4,
                    hjust = 0, nudge_y = 2, ylim=c(-1*input_data %>% select(chi2) %>% abs() %>% max()+1, -1), nudge_x = 0.04, direction = "y", segment.colour = NA, show.legend = FALSE, box.padding = 0.08) + 
    geom_segment(aes(y = chi2, x = question_long, yend = 0, xend = question_long, color=group_name)) + 
    scale_y_continuous(limits = c(-13,
                                  input_data %>% select(chi2) %>% abs() %>% max()), breaks = ) +
    scale_color_manual(values = colors) +
    scale_fill_manual(values = colors) +
    ylab("Chi2") +
    theme_bw() +
    #coord_flip() + 
    theme(axis.title.y = element_text(size = 18, face = "bold"),
          plot.title = element_text(hjust = 0.5, size = 20, face = "bold"),
          axis.title.x = element_blank(),
          axis.text.x = element_text(size = 16, face = "bold"),
          panel.border = element_rect(colour = "black", fill=NA, size=1.5),
          text  = element_text(size=22),
          panel.background = element_rect(fill = NA,
                                          colour = NA),
          panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(),
          axis.line = element_line(size = 1),
          axis.text = element_text(colour = "black", size = 16),
          legend.position = "bottom",
          legend.title = element_blank(),
          legend.key = element_rect(fill = NA))
  
  ggsave(paste0(figures, "/Figure_3a", ".pdf"), 
         plot = graph, width = 7, height = 8)
  
}
