clear all

local dir `c(pwd)'


	if substr("`dir'",1,15) == "/Users/beatrice"{
	global user "/Users/beatrice"
	}
.

global dir "$user/Desktop/REPLICATION_PACKET" // working folder
global data "$dir/Data"
global fig_path "$dir/Output"






set more off
set maxvar 7000, perm



use "$data/DTM_estate", clear

gen distribution_topic = 0
	replace distribution_topic = 1 if c_middl_class >=1 | c_work_class >= 1 | c_low_incom >=1 | c_wealthi >=1 | c_millionair>=1 | c_rich>=1 | ///
	c_billionair>=1 |  (c_corpor > 0 & c_pay > 0) | (c_corpor > 0 & c_tax > 0) |c_poor>0 | c_inequ>0 

	
gen fairness_topic = 0
	replace fairness_topic =1 if c_fair>0 | c_unfair>0

	
gen gov_spend_topic = 0 
	replace gov_spend_topic = 1 if (c_govern_spend > 0 & c_high > 0) | (c_govern_spend > 0 & c_cut > 0) | c_deficit > 0 | c_debt > 0 | (c_govern > 0 & c_wast > 0) | ///
	(c_balanc > 0 & c_budget > 0) | (c_govern > 0 & c_budget > 0) | (c_govern > 0 & c_control > 0 & c_spend > 0)

gen public_topic=0
	replace public_topic=1 if c_infrastructur>0 | c_educ>0 |  c_healthcar>0 |  c_health_care>0 

	
	
gen efficiency_topic = 0
	replace efficiency_topic = 1 if (c_hurt > 0 & c_economi > 0) | c_work_hard > 0 | c_flat > 0  


	
gen loopholes_topic = 0
	replace loopholes_topic = 1 if c_loophol>0 | c_lawyer >0 | c_account>0  | c_evad>0 | c_avoid_tax>0 | c_evas>0

	
gen doubletax_topic=0
	replace doubletax_topic=1 if c_alreadi_tax>0 | c_alreadi_pay>0 |  c_alreadi_paid>0 |  c_tax_alreadi>0 | (c_twice>0 & c_pay>0) |(c_twice>0 & c_tax>0) |(c_alreadi>0 & c_been_tax>0) | (c_alreadi_been>0 & c_tax>0) | (c_alreadi>0 & c_been_paid>0) | (c_alreadi_been>0 & c_paid>0) 


gen grieve_topic=0
	replace grieve_topic=1 if c_griev>0 | c_buri>0  | c_funer>0  

	
gen dontknow_topic=0
	replace dontknow_topic=1 if c_knowledg_enough>0 | c_not_know>0 |  c_realli_know>0 |  c_idk>0 |  c_not_sure>0 |  c_inform_enough>0 | c_know_enough>0 | c_unsur>0
	
	
keep responseid question distribution_topic fairness_topic gov_spend_topic efficiency_topic  loopholes_topic grieve_topic doubletax_topic public_topic dontknow_topic
keep if question=="Q02002" | question=="Q02003" | question=="Q02004" | question=="Q02005" |  question=="Q02006" |  question=="Q02007" | question=="Q02008"





rename responseid ResponseId
reshape wide distribution_topic fairness_topic gov_spend_topic efficiency_topic loopholes_topic grieve_topic doubletax_topic public_topic dontknow_topic, i(ResponseId) j(question) string
tempfile topic_DTM_wide
save `topic_DTM_wide'


use "$data/data_estate_tax.dta", clear
merge 1:1 ResponseId using `topic_DTM_wide'
save "$data/Figure_2b", replace











*****************************************
*                                       *
*              FIGURES                  *
*                                       *
*****************************************

set more off
. grstyle init

use "$data/Figure_2b", clear

foreach x in 2 3 4 5 6 7 {
rename distribution_topicQ0200`x' topic_1Q0200`x'
rename fairness_topicQ0200`x' topic_2Q0200`x'
rename gov_spend_topicQ0200`x' topic_3Q0200`x'
rename efficiency_topicQ0200`x' topic_4Q0200`x'
rename loopholes_topicQ0200`x' topic_5Q0200`x'
rename doubletax_topicQ0200`x' topic_6Q0200`x'
rename grieve_topicQ0200`x' topic_7Q0200`x'
rename public_topicQ0200`x' topic_8Q0200`x'
rename dontknow_topicQ0200`x' topic_9Q0200`x'
}
.

********************************************
*** Within-group distributions, by topic ***
********************************************

****************************
*** Political preference ***
****************************

**********
* Q02002 *
**********

foreach i in 1 2 3 4 {
preserve
keep if candidate_econ==`i'
egen sum_topic_Q02002_`i'=rowtotal(topic_1Q02002 topic_2Q02002 topic_3Q02002 topic_4Q02002 topic_5Q02002 topic_6Q02002 topic_7Q02002 topic_8Q02002 topic_9Q02002) 
egen sum_Q02002_`i'=total(sum_topic_Q02002_`i')
foreach x in 1 2 3 4 5 6 7 8 9 {
egen sum_topic_`x'_Q02002_`i'=total(topic_`x'Q02002)
sca ratio_`x'_Q02002_`i'=(sum_topic_`x'_Q02002_`i'/sum_Q02002_`i')*100 
}
restore
}
.


preserve

clear
set obs 9

egen topic=seq()

label val topic topic

gen candidate_1=.
gen candidate_2=.
gen candidate_3=.
gen candidate_4=.


set more off
foreach i in 1 2 3 4 {
foreach x in 1 2 3 4 5 6 7 8 9 {
replace candidate_`i'=ratio_`x'_Q02002_`i' if topic==`x'
}
}
.

. grstyle set plain
. graph set window fontface "Arial"
graph bar candidate_* if topic==1,  bargap(10) ///
graphregion(color(white) lwidth(large)) plotregion(style(none)) ///
title("{bf:Distribution}", size(huge)) ysca(titlegap(2)) ysc(range(0 50)) subtitle(" ") ///
ylabel(0(10)50) legend(off) ///
ylabel(,angle(0)) yscale(lwidth(medthick)) ///
bar(1, color("26 64 101")) bar(2, color("88 116 143"))  bar(3, color("204 100 86")) bar(4, color("185 42 23")) 
graph save "$fig_path/temp/fig1.gph", replace


. grstyle set plain
. graph set window fontface "Arial"
graph bar candidate_* if topic==2,  bargap(10) ///
graphregion(color(white) lwidth(large)) plotregion(style(none)) ///
title("{bf:Fairness}", size(huge)) ysca(titlegap(2)) ysc(range(0 50)) subtitle(" ") ///
ylabel(0(10)50) legend(off) ///
ylabel(,angle(0)) yscale(lwidth(medthick)) ///
bar(1, color("26 64 101")) bar(2, color("88 116 143"))  bar(3, color("204 100 86")) bar(4, color("185 42 23")) 
graph save "$fig_path/temp/fig2.gph", replace


. grstyle set plain
. graph set window fontface "Arial"
graph bar candidate_* if topic==3,  bargap(10) ///
graphregion(color(white) lwidth(large)) plotregion(style(none)) ///
title("{bf:Gov. Spending}", size(huge)) ysca(titlegap(2)) ysc(range(0 50)) subtitle(" ") ///
ylabel(0(10)50) legend(off) ///
ylabel(,angle(0)) yscale(lwidth(medthick)) ///
bar(1, color("26 64 101")) bar(2, color("88 116 143"))  bar(3, color("204 100 86")) bar(4, color("185 42 23")) 
graph save "$fig_path/temp/fig3.gph", replace

. grstyle set plain
. graph set window fontface "Arial"
graph bar candidate_* if topic==4,  bargap(10) ///
graphregion(color(white) lwidth(large)) plotregion(style(none)) ///
title("{bf:Efficiency}", size(huge)) ysca(titlegap(2)) ysc(range(0 50)) subtitle(" ") ///
ylabel(0(10)50) legend(off) ///
ylabel(,angle(0)) yscale(lwidth(medthick)) ///
bar(1, color("26 64 101")) bar(2, color("88 116 143"))  bar(3, color("204 100 86")) bar(4, color("185 42 23")) 
graph save "$fig_path/temp/fig4.gph", replace

. grstyle set plain
. graph set window fontface "Arial"
graph bar candidate_* if topic==5,  bargap(10) ///
graphregion(color(white) lwidth(large)) plotregion(style(none)) ///
title("{bf:Loopholes}", size(huge)) ysca(titlegap(2)) ysc(range(0 50)) subtitle(" ") ///
ylabel(0(10)50) legend(off) ///
ylabel(,angle(0)) yscale(lwidth(medthick)) ///
bar(1, color("26 64 101")) bar(2, color("88 116 143"))  bar(3, color("204 100 86")) bar(4, color("185 42 23")) 
graph save "$fig_path/temp/fig5.gph", replace

. grstyle set plain
. graph set window fontface "Arial"
graph bar candidate_* if topic==6,  bargap(10) ///
graphregion(color(white)) plotregion(color(white)) ///
title("{bf:Double Tax}", size(huge)) ysca(titlegap(2)) ysc(range(0 50))subtitle(" ") ///
ylabel(,angle(0)) yscale(lwidth(medthick)) ///
ylabel(0(10)50) legend(off)  ///
bar(1, color("26 64 101")) bar(2, color("88 116 143"))  bar(3, color("204 100 86")) bar(4, color("185 42 23"))
graph save "$fig_path/temp/fig6.gph", replace

. grstyle set plain
. graph set window fontface "Arial"
graph bar candidate_* if topic==7,  bargap(10) ///
graphregion(color(white)) plotregion(color(white)) ///
title("{bf:Grieve}", size(huge)) ysca(titlegap(2)) subtitle(" ") ///
ylabel(,angle(0)) yscale(lwidth(medthick)) ///
ylabel(0(10)50) legend(off)  ///
bar(1, color("26 64 101")) bar(2, color("88 116 143"))  bar(3, color("204 100 86")) bar(4, color("185 42 23"))
graph save "$fig_path/temp/fig7.gph", replace

. grstyle set plain
. graph set window fontface "Arial"
graph bar candidate_* if topic==8,  bargap(10) ///
graphregion(color(white)) plotregion(color(white)) ///
title("{bf:Public Goods}", size(huge)) ysca(titlegap(2)) ysc(range(0 50)) subtitle(" ") ///
ylabel(,angle(0)) yscale(lwidth(medthick)) ///
ylabel(0(10)50) legend(off)  ///
bar(1, color("26 64 101")) bar(2, color("88 116 143"))  bar(3, color("204 100 86")) bar(4, color("185 42 23"))
graph save "$fig_path/temp/fig8.gph", replace

. grstyle set plain
. graph set window fontface "Arial"
graph bar candidate_* if topic==9,  bargap(10) ///
graphregion(color(white)) plotregion(color(white)) ///
title("{bf:Don't Know}", size(huge)) ysca(titlegap(2)) ysc(range(0 50)) subtitle(" ") ///
ylabel(,angle(0)) yscale(lwidth(medthick)) ///
ylabel(0(10)50) legend(order(1 2 3 4) col(2) symysize(3) symxsize(4) size(medium) lab(1 "Clinton Liberal") lab(2 "Clinton Moderate") lab(3 "Trump Moderate") lab(4 "Trump Conservative") rows(1))  ///
bar(1, color("26 64 101")) bar(2, color("88 116 143"))  bar(3, color("204 100 86")) bar(4, color("185 42 23"))
graph save "$fig_path/temp/fig9.gph", replace


grc1leg "$fig_path/temp/fig1.gph" "$fig_path/temp/fig2.gph" "$fig_path/temp/fig3.gph" "$fig_path/temp/fig4.gph" "$fig_path/temp/fig5.gph" "$fig_path/temp/fig6.gph" "$fig_path/temp/fig7.gph" "$fig_path/temp/fig8.gph" "$fig_path/temp/fig9.gph", cols(5) graphregion(color(white)) plotregion(color(white)) iscale(0.7) legendfrom("$fig_path/temp/fig9.gph") 
graph display, ysize(5) xsize(10)
graph export "$fig_path/Figure_2b.pdf", replace

restore

